[binutils-gdb] [gdb/tui] Expand WDB reference

Tom de Vries via Gdb-cvs <[email protected]>
Newsgroups gmane.comp.gdb.cvs
Message-ID <[email protected]>
https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=a6602675786257f53094ff1df58e24a70c01c2b9

commit a6602675786257f53094ff1df58e24a70c01c2b9
Author: Tom de Vries <[email protected]>
Date:   Fri Apr 24 19:30:41 2026 +0200

    [gdb/tui] Expand WDB reference
    
    In gdb/tui/tui.c I came across:
    ...
    /* General functions for the WDB TUI.
    ...
    
    Initially I thought this was a WDB->GDB typo, but after searching a bit I
    found out that this is a reference to HP Wildebeest, a port of GDB to HP-UX.
    
    Change the comment line to use "General functions for the GDB TUI", and
    instead mention it here in a more descriptive form:
    ...
    -   Contributed by Hewlett-Packard Company.
    +   Contributed by Hewlett-Packard Company.  Developed as part of HP Wildebeest
    +   (WDB), a port of GDB to HP-UX.
    ...
    
    While we're at it, remove a pointless "This is a sample program for the HP WDB
    debugger" note in gdb.base/average.c.
    
    Approved-By: Tom Tromey <[email protected]>

Diff:
---
 gdb/testsuite/gdb.base/average.c | 2 --
 gdb/tui/tui.c                    | 5 +++--
 2 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/gdb/testsuite/gdb.base/average.c b/gdb/testsuite/gdb.base/average.c
index b99dcf49629..1dac44590da 100644
--- a/gdb/testsuite/gdb.base/average.c
+++ b/gdb/testsuite/gdb.base/average.c
@@ -1,5 +1,3 @@
-/* This is a sample program for the HP WDB debugger. */
-
 #include <stdio.h>
 #include <stdlib.h>
 
diff --git a/gdb/tui/tui.c b/gdb/tui/tui.c
index 5e39eef71c6..35c3b80603d 100644
--- a/gdb/tui/tui.c
+++ b/gdb/tui/tui.c
@@ -1,8 +1,9 @@
 /* General functions for the WDB TUI.
 
    Copyright (C) 1998-2026 Free Software Foundation, Inc.
 
-   Contributed by Hewlett-Packard Company.
+   Contributed by Hewlett-Packard Company.  Developed as part of HP Wildebeest
+   (WDB), a port of GDB to HP-UX.
 
    This file is part of GDB.
@@ -1,8 +1,9 @@
-/* General functions for the WDB TUI.
+/* General functions for the GDB TUI.
 
    Copyright (C) 1998-2026 Free Software Foundation, Inc.
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.